@@ -5,14 +5,17 @@ import warnings
 from asgiref.sync import sync_to_async
 
 
-class RemovedInNextVersionWarning(DeprecationWarning):
+class RemovedInDjango40Warning(DeprecationWarning):
     pass
 
 
-class RemovedInDjango40Warning(PendingDeprecationWarning):
+class RemovedInDjango41Warning(PendingDeprecationWarning):
     pass
 
 
+RemovedInNextVersionWarning = RemovedInDjango40Warning
+
+
 class warn_about_renamed_method:
     def __init__(self, class_name, old_method_name, new_method_name, deprecation_warning):
         self.class_name = class_name
